aboutsummaryrefslogtreecommitdiffhomepage
path: root/internal/app/config.go
diff options
context:
space:
mode:
authorOphestra Umiker <cat@ophivana.moe>2024-12-06 04:25:33 +0900
committerOphestra Umiker <cat@ophivana.moe>2024-12-06 04:25:33 +0900
commitb3ef53b193bdf764d8f04e19ea47901b71eec10b (patch)
treef842120ed936715340e4fe48a8913766c65d7581 /internal/app/config.go
parent8d0573405a8a58a57c39b008150d75d3be2894c2 (diff)
app: integrate security-context-v1
Should be able to get rid of XDG_RUNTIME_DIR share after this. Signed-off-by: Ophestra Umiker <cat@ophivana.moe>
Diffstat (limited to 'internal/app/config.go')
-rw-r--r--internal/app/config.go18
1 files changed, 9 insertions, 9 deletions
diff --git a/internal/app/config.go b/internal/app/config.go
index 298925de..758dcd08 100644
--- a/internal/app/config.go
+++ b/internal/app/config.go
@@ -62,8 +62,8 @@ type SandboxConfig struct {
NoNewSession bool `json:"no_new_session,omitempty"`
// map target user uid to privileged user uid in the user namespace
MapRealUID bool `json:"map_real_uid"`
- // mediated access to wayland socket
- Wayland bool `json:"wayland,omitempty"`
+ // direct access to wayland socket
+ DirectWayland bool `json:"direct_wayland,omitempty"`
// final environment variables
Env map[string]string `json:"env"`
@@ -190,13 +190,13 @@ func Template() *Config {
Outer: "/var/lib/persist/home/org.chromium.Chromium",
Inner: "/var/lib/fortify",
Sandbox: &SandboxConfig{
- Hostname: "localhost",
- UserNS: true,
- Net: true,
- NoNewSession: true,
- MapRealUID: true,
- Dev: true,
- Wayland: false,
+ Hostname: "localhost",
+ UserNS: true,
+ Net: true,
+ NoNewSession: true,
+ MapRealUID: true,
+ Dev: true,
+ DirectWayland: false,
// example API credentials pulled from Google Chrome
// DO NOT USE THESE IN A REAL BROWSER
Env: map[string]string{